==> mktcenter-service-1.0.2-20190918.084142-129-sources.jar: com/bizvane/mktcenterservice/models/vo/ActivityVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysDimSkuPo;
import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.couponfacade.models.po.CouponEntityPO;
import com.bizvane.couponfacade.models.vo.CouponDetailResponseVO;
import com.bizvane.couponfacade.models.vo.CouponFindCouponCountResponseVO;
import com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPO;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/6 20:07
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class ActivityVO extends MktActivityPO {
    private String sourceWay;
    private String pageUrl;
    private Integer mbrConditionType;
    private String mbrCondition;
    private BigDecimal orderAmount;
    private Boolean totalNumType;
    private Integer totalNum;
    private Integer activityInfoType;
    private String payName;
    private Integer payMoney;
    private Integer payReduced;
    private Integer payId;
    private Long mktCouponId;
    //有过期券  为true   没有为false
    private Boolean couponIsOrNo=false;
    //评价活动字数
    private Integer wordCount;
    private Boolean storeLimit;
    //活动描述、简介
    private String activityInfo;
    //开卡
    private Integer offlineCardStatus;
    //开卡时等级编号. mbr_level_code
    private String mbrLevelCode;
    //活动针对的会员等级名称
    private String mbrLevelName;
    //针对的会员类型：0,所有类型，1微信会员
    private Integer memberType;
    //提前多少日进行
    private Integer daysAhead;
    //订单最低金额
    private String orderMinPrice;
    //签到方式：1连续签到，2累计签到，3单日签到
    private Integer signType;
    //积分方式
    private String integralType;
    //赠送积分基数
    private Long integralBasis;
    //每次增加的数值
    private Long integralAddend;
    //增加后的最高积分上限
    private Long integralMax;
    //创建时间开始
    private Date createDateStart;
    //创建时间结束
    private Date createDateEnd;
    //二维码
    private String qrcode;
    //订单来源：1线下订单，2微商城订单
    private Integer orderSource;//订单来源

    private Integer perPersonPerDayMax;

    private Integer perPersonMax;
    //券定义id
    private Long couponDefinitionId;
    //券号
    private String couponCode;
    //券名称
    private String couponName;
    //是否可领取
    private Boolean canReceive;
   //活动明细id
    private Long mktActivityManualId;
    //券实例
    private CouponEntityPO couponEntityPO;
    //券定义
    private CouponDefinitionPO couponDefinitionPO;

    private CouponFindCouponCountResponseVO couponFindCouponCountResponseVO;
    //通过id查询券实例
    private CouponDetailResponseVO couponDetailResponseVO;

    private CouponDetailResponseBO CouponDetailResponseBO;
    //核销率
    private String useCouponRate;
    //会员编号
    private String memberCode;
    //商品限制名单
    private String commodityLimitList;
    //门店限制名单
    private String storeLimitList;
    //商品限制状态：0不限制，1限制
    private Boolean isCommodityLimit;
    //商品限制类型：1黑名单，2白名单
    private Integer commodityLimitType;
    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //立即发送：1是，0否
    private Boolean sendImmediately;
    //发送时间
    private Date sendTime;
    //门店实体类
    private List<SysStorePo> sysStorePos;
    //商品实体类
    private List<SysDimSkuPo> sysDimSkuPos;
    //入会满多少月
    private Integer registerMonths;
    //判断创建时候过滤禁用状态
    private String stop;
    //服务门店
    private Long serviceStoreId;
    //活动详情图片
    private String activityDetailImg;

    public String getActivityDetailImg() {
        return activityDetailImg;
    }

    public void setActivityDetailImg(String activityDetailImg) {
        this.activityDetailImg = activityDetailImg;
    }

    public Long getServiceStoreId() {
        return serviceStoreId;
    }

    public void setServiceStoreId(Long serviceStoreId) {
        this.serviceStoreId = serviceStoreId;
    }

    public String getStop() {
        return stop;
    }

    public void setStop(String stop) {
        this.stop = stop;
    }

    public Integer getRegisterMonths() {
        return registerMonths;
    }

    public void setRegisterMonths(Integer registerMonths) {
        this.registerMonths = registerMonths;
    }

    public List<SysDimSkuPo> getSysDimSkuPos() {
        return sysDimSkuPos;
    }

    public void setSysDimSkuPos(List<SysDimSkuPo> sysDimSkuPos) {
        this.sysDimSkuPos = sysDimSkuPos;
    }

    public List<SysStorePo> getSysStorePos() {
        return sysStorePos;
    }

    public void setSysStorePos(List<SysStorePo> sysStorePos) {
        this.sysStorePos = sysStorePos;
    }
    @Override
    public Boolean getSendImmediately() {
        return sendImmediately;
    }

    @Override
    public void setSendImmediately(Boolean sendImmediately) {
        this.sendImmediately = sendImmediately;
    }

    @Override
    public Date getSendTime() {
        return sendTime;
    }

    @Override
    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public String getCommodityLimitList() {
        return commodityLimitList;
    }

    public CouponDetailResponseVO getCouponDetailResponseVO() {
        return couponDetailResponseVO;
    }

    public void setCouponDetailResponseVO(CouponDetailResponseVO couponDetailResponseVO) {
        this.couponDetailResponseVO = couponDetailResponseVO;
    }

    public void setCommodityLimitList(String commodityLimitList) {
        this.commodityLimitList = commodityLimitList;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    public Boolean getCommodityLimit() {
        return isCommodityLimit;
    }

    public void setCommodityLimit(Boolean commodityLimit) {
        isCommodityLimit = commodityLimit;
    }

    public Integer getCommodityLimitType() {
        return commodityLimitType;
    }

    public void setCommodityLimitType(Integer commodityLimitType) {
        this.commodityLimitType = commodityLimitType;
    }

//    public Boolean getStoreLimit() {
//        return isStoreLimit;
//    }
//
//    public void setStoreLimit(Boolean storeLimit) {
//        isStoreLimit = storeLimit;
//    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getActivityInfo() {
        return activityInfo;
    }

    public void setActivityInfo(String activityInfo) {
        this.activityInfo = activityInfo;
    }

    public Integer getOfflineCardStatus() {
        return offlineCardStatus;
    }

    public void setOfflineCardStatus(Integer offlineCardStatus) {
        this.offlineCardStatus = offlineCardStatus;
    }

    public String getMbrLevelCode() {
        return mbrLevelCode;
    }

    public void setMbrLevelCode(String mbrLevelCode) {
        this.mbrLevelCode = mbrLevelCode;
    }

    public String getMbrLevelName() {
        return mbrLevelName;
    }

    public void setMbrLevelName(String mbrLevelName) {
        this.mbrLevelName = mbrLevelName;
    }

    public Integer getMemberType() {
        return memberType;
    }

    public void setMemberType(Integer memberType) {
        this.memberType = memberType;
    }

    public Integer getDaysAhead() {
        return daysAhead;
    }

    public void setDaysAhead(Integer daysAhead) {
        this.daysAhead = daysAhead;
    }

    public String getOrderMinPrice() {
        return orderMinPrice;
    }

    public void setOrderMinPrice(String orderMinPrice) {
        this.orderMinPrice = orderMinPrice;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public String getIntegralType() {
        return integralType;
    }

    public void setIntegralType(String integralType) {
        this.integralType = integralType;
    }

    public Long getIntegralBasis() {
        return integralBasis;
    }

    public void setIntegralBasis(Long integralBasis) {
        this.integralBasis = integralBasis;
    }

    public Long getIntegralAddend() {
        return integralAddend;
    }

    public void setIntegralAddend(Long integralAddend) {
        this.integralAddend = integralAddend;
    }

    public Long getIntegralMax() {
        return integralMax;
    }

    public void setIntegralMax(Long integralMax) {
        this.integralMax = integralMax;
    }

    public Date getCreateDateStart() {
        return createDateStart;
    }

    public Date getCreateDateEnd() {
        return createDateEnd;
    }

    public void setCreateDateStart(Date createDateStart) {
        this.createDateStart = createDateStart;
    }

    public void setCreateDateEnd(Date createDateEnd) {
        this.createDateEnd = createDateEnd;
    }

    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

    public Integer getPerPersonPerDayMax() {
        return perPersonPerDayMax;
    }

    public void setPerPersonPerDayMax(Integer perPersonPerDayMax) {
        this.perPersonPerDayMax = perPersonPerDayMax;
    }

    public Integer getPerPersonMax() {
        return perPersonMax;
    }

    public void setPerPersonMax(Integer perPersonMax) {
        this.perPersonMax = perPersonMax;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Boolean getCanReceive() {
        return canReceive;
    }

    public void setCanReceive(Boolean canReceive) {
        this.canReceive = canReceive;
    }

    public Long getMktActivityManualId() {
        return mktActivityManualId;
    }

    public void setMktActivityManualId(Long mktActivityManualId) {
        this.mktActivityManualId = mktActivityManualId;
    }

    public CouponEntityPO getCouponEntityPO() {
        return couponEntityPO;
    }

    public void setCouponEntityPO(CouponEntityPO couponEntityPO) {
        this.couponEntityPO = couponEntityPO;
    }

    public CouponFindCouponCountResponseVO getCouponFindCouponCountResponseVO() {
        return couponFindCouponCountResponseVO;
    }

    public void setCouponFindCouponCountResponseVO(CouponFindCouponCountResponseVO couponFindCouponCountResponseVO) {
        this.couponFindCouponCountResponseVO = couponFindCouponCountResponseVO;
    }

    public String getUseCouponRate() {
        return useCouponRate;
    }

    public void setUseCouponRate(String useCouponRate) {
        this.useCouponRate = useCouponRate;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }


    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public Boolean getStoreLimit() {
        return storeLimit;
    }

    public void setStoreLimit(Boolean storeLimit) {
        this.storeLimit = storeLimit;
    }

    public Integer getWordCount() {
        return wordCount;
    }

    public void setWordCount(Integer wordCount) {
        this.wordCount = wordCount;
    }

    public Boolean getCouponIsOrNo() {
        return couponIsOrNo;
    }

    public void setCouponIsOrNo(Boolean couponIsOrNo) {
        this.couponIsOrNo = couponIsOrNo;
    }

    public Long getMktCouponId() {
        return mktCouponId;
    }

    public void setMktCouponId(Long mktCouponId) {
        this.mktCouponId = mktCouponId;
    }

    public String getPayName() {
        return payName;
    }

    public void setPayName(String payName) {
        this.payName = payName;
    }

    public Integer getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(Integer payMoney) {
        this.payMoney = payMoney;
    }

    public Integer getPayReduced() {
        return payReduced;
    }

    public void setPayReduced(Integer payReduced) {
        this.payReduced = payReduced;
    }

    public Integer getPayId() {
        return payId;
    }

    public void setPayId(Integer payId) {
        this.payId = payId;
    }

    public Integer getActivityInfoType() {
        return activityInfoType;
    }

    public void setActivityInfoType(Integer activityInfoType) {
        this.activityInfoType = activityInfoType;
    }

    public com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO getCouponDetailResponseBO() {
        return CouponDetailResponseBO;
    }

    public void setCouponDetailResponseBO(com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO couponDetailResponseBO) {
        CouponDetailResponseBO = couponDetailResponseBO;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Boolean getTotalNumType() {
        return totalNumType;
    }

    public void setTotalNumType(Boolean totalNumType) {
        this.totalNumType = totalNumType;
    }

    public BigDecimal getOrderAmount() {
        return orderAmount;
    }

    public void setOrderAmount(BigDecimal orderAmount) {
        this.orderAmount = orderAmount;
    }

    @Override
    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    @Override
    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    @Override
    public String getMbrCondition() {
        return mbrCondition;
    }

    @Override
    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public String getSourceWay() {
        return sourceWay;
    }

    public void setSourceWay(String sourceWay) {
        this.sourceWay = sourceWay;
    }
}

==> mktcenter-service-2.0.0-20200323.084943-42-sources.jar: com/bizvane/mktcenterservice/models/vo/ActivityVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysDimSkuPo;
import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.couponfacade.models.po.CouponEntityPO;
import com.bizvane.couponfacade.models.vo.CouponDetailResponseVO;
import com.bizvane.couponfacade.models.vo.CouponFindCouponCountResponseVO;
import com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPO;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/6 20:07
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class ActivityVO extends MktActivityPO {
    private Integer dayOrMonth;
    private String perMensem;
    private String tag;
    private Integer canCheck;
    private String sourceWay;
    private String pageUrl;
    private Integer mbrConditionType;
    private String mbrCondition;
    private BigDecimal orderAmount;
    private Boolean totalNumType;
    private Integer totalNum;
    private Integer activityInfoType;
    private String payName;
    private Integer payMoney;
    private Integer payReduced;
    private Integer payId;
    private Long mktCouponId;
    //有过期券  为true   没有为false
    private Boolean couponIsOrNo=false;
    //评价活动字数
    private Integer wordCount;
    private Boolean storeLimit;
    //活动描述、简介
    private String activityInfo;
    private  String organizationCode;
    //开卡
    private Integer offlineCardStatus;
    //开卡时等级编号. mbr_level_code
    private String mbrLevelCode;
    //活动针对的会员等级名称
    private String mbrLevelName;
    //针对的会员类型：0,所有类型，1微信会员
    private Integer memberType;
    //提前多少日进行
    private Integer daysAhead;
    //订单最低金额
    private String orderMinPrice;
    private String orderMaxPrice;
    private String  canSaveType;
    //签到方式：1连续签到，2累计签到，3单日签到
    private Integer signType;
    //积分方式
    private String integralType;
    //赠送积分基数
    private Long integralBasis;
    //每次增加的数值
    private Long integralAddend;
    //增加后的最高积分上限
    private Long integralMax;
    //创建时间开始
    private Date createDateStart;
    //创建时间结束
    private Date createDateEnd;
    //二维码
    private String qrcode;
    //订单来源：1线下订单，2微商城订单
    private Integer orderSource;//订单来源

    private Integer perPersonPerDayMax;

    private Integer perPersonMax;
    //券定义id
    private Long couponDefinitionId;
    //券号
    private String couponCode;
    //券名称
    private String couponName;
    //是否可领取
    private Boolean canReceive;
   //活动明细id
    private Long mktActivityManualId;
    //券实例
    private CouponEntityPO couponEntityPO;
    //券定义
    private CouponDefinitionPO couponDefinitionPO;

    private CouponFindCouponCountResponseVO couponFindCouponCountResponseVO;
    //通过id查询券实例
    private CouponDetailResponseVO couponDetailResponseVO;

    private CouponDetailResponseBO CouponDetailResponseBO;
    //核销率
    private String useCouponRate;
    //会员编号
    private String memberCode;
    //商品限制名单
    private String commodityLimitList;
    //门店限制名单
    private String storeLimitList;
    //商品限制状态：0不限制，1限制
    private Boolean isCommodityLimit;
    //商品限制类型：1黑名单，2白名单
    private Integer commodityLimitType;
    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //立即发送：1是，0否
    private Boolean sendImmediately;
    //发送时间
    private Date sendTime;
    //门店实体类
    private List<SysStorePo> sysStorePos;
    //商品实体类
    private List<SysDimSkuPo> sysDimSkuPos;
    //入会满多少月
    private Integer registerMonths;
    //判断创建时候过滤禁用状态
    private String stop;
    //服务门店
    private Long serviceStoreId;
    //活动详情图片
    private String activityDetailImg;

    public String getActivityDetailImg() {
        return activityDetailImg;
    }

    public void setActivityDetailImg(String activityDetailImg) {
        this.activityDetailImg = activityDetailImg;
    }

    public Long getServiceStoreId() {
        return serviceStoreId;
    }

    public void setServiceStoreId(Long serviceStoreId) {
        this.serviceStoreId = serviceStoreId;
    }

    public String getStop() {
        return stop;
    }

    public void setStop(String stop) {
        this.stop = stop;
    }

    public Integer getRegisterMonths() {
        return registerMonths;
    }

    public void setRegisterMonths(Integer registerMonths) {
        this.registerMonths = registerMonths;
    }

    public List<SysDimSkuPo> getSysDimSkuPos() {
        return sysDimSkuPos;
    }

    public void setSysDimSkuPos(List<SysDimSkuPo> sysDimSkuPos) {
        this.sysDimSkuPos = sysDimSkuPos;
    }

    public List<SysStorePo> getSysStorePos() {
        return sysStorePos;
    }

    public void setSysStorePos(List<SysStorePo> sysStorePos) {
        this.sysStorePos = sysStorePos;
    }
    @Override
    public Boolean getSendImmediately() {
        return sendImmediately;
    }

    @Override
    public void setSendImmediately(Boolean sendImmediately) {
        this.sendImmediately = sendImmediately;
    }

    @Override
    public Date getSendTime() {
        return sendTime;
    }

    @Override
    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public String getCommodityLimitList() {
        return commodityLimitList;
    }

    public CouponDetailResponseVO getCouponDetailResponseVO() {
        return couponDetailResponseVO;
    }

    public void setCouponDetailResponseVO(CouponDetailResponseVO couponDetailResponseVO) {
        this.couponDetailResponseVO = couponDetailResponseVO;
    }

    public void setCommodityLimitList(String commodityLimitList) {
        this.commodityLimitList = commodityLimitList;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    public Boolean getCommodityLimit() {
        return isCommodityLimit;
    }

    public void setCommodityLimit(Boolean commodityLimit) {
        isCommodityLimit = commodityLimit;
    }

    public Integer getCommodityLimitType() {
        return commodityLimitType;
    }

    public void setCommodityLimitType(Integer commodityLimitType) {
        this.commodityLimitType = commodityLimitType;
    }

//    public Boolean getStoreLimit() {
//        return isStoreLimit;
//    }
//
//    public void setStoreLimit(Boolean storeLimit) {
//        isStoreLimit = storeLimit;
//    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getActivityInfo() {
        return activityInfo;
    }

    public void setActivityInfo(String activityInfo) {
        this.activityInfo = activityInfo;
    }

    public Integer getOfflineCardStatus() {
        return offlineCardStatus;
    }

    public void setOfflineCardStatus(Integer offlineCardStatus) {
        this.offlineCardStatus = offlineCardStatus;
    }

    public String getMbrLevelCode() {
        return mbrLevelCode;
    }

    public void setMbrLevelCode(String mbrLevelCode) {
        this.mbrLevelCode = mbrLevelCode;
    }

    public String getMbrLevelName() {
        return mbrLevelName;
    }

    public void setMbrLevelName(String mbrLevelName) {
        this.mbrLevelName = mbrLevelName;
    }

    public Integer getMemberType() {
        return memberType;
    }

    public void setMemberType(Integer memberType) {
        this.memberType = memberType;
    }

    public Integer getDaysAhead() {
        return daysAhead;
    }

    public void setDaysAhead(Integer daysAhead) {
        this.daysAhead = daysAhead;
    }

    public String getOrderMinPrice() {
        return orderMinPrice;
    }

    public void setOrderMinPrice(String orderMinPrice) {
        this.orderMinPrice = orderMinPrice;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public String getIntegralType() {
        return integralType;
    }

    public void setIntegralType(String integralType) {
        this.integralType = integralType;
    }

    public Long getIntegralBasis() {
        return integralBasis;
    }

    public void setIntegralBasis(Long integralBasis) {
        this.integralBasis = integralBasis;
    }

    public Long getIntegralAddend() {
        return integralAddend;
    }

    public void setIntegralAddend(Long integralAddend) {
        this.integralAddend = integralAddend;
    }

    public Long getIntegralMax() {
        return integralMax;
    }

    public void setIntegralMax(Long integralMax) {
        this.integralMax = integralMax;
    }

    public Date getCreateDateStart() {
        return createDateStart;
    }

    public Date getCreateDateEnd() {
        return createDateEnd;
    }

    public void setCreateDateStart(Date createDateStart) {
        this.createDateStart = createDateStart;
    }

    public void setCreateDateEnd(Date createDateEnd) {
        this.createDateEnd = createDateEnd;
    }

    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

    public Integer getPerPersonPerDayMax() {
        return perPersonPerDayMax;
    }

    public void setPerPersonPerDayMax(Integer perPersonPerDayMax) {
        this.perPersonPerDayMax = perPersonPerDayMax;
    }

    public Integer getPerPersonMax() {
        return perPersonMax;
    }

    public void setPerPersonMax(Integer perPersonMax) {
        this.perPersonMax = perPersonMax;
    }

    public String getCouponCode() {
        return couponCode;
    }

    public void setCouponCode(String couponCode) {
        this.couponCode = couponCode;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public Boolean getCanReceive() {
        return canReceive;
    }

    public void setCanReceive(Boolean canReceive) {
        this.canReceive = canReceive;
    }

    public Long getMktActivityManualId() {
        return mktActivityManualId;
    }

    public void setMktActivityManualId(Long mktActivityManualId) {
        this.mktActivityManualId = mktActivityManualId;
    }

    public CouponEntityPO getCouponEntityPO() {
        return couponEntityPO;
    }

    public void setCouponEntityPO(CouponEntityPO couponEntityPO) {
        this.couponEntityPO = couponEntityPO;
    }

    public CouponFindCouponCountResponseVO getCouponFindCouponCountResponseVO() {
        return couponFindCouponCountResponseVO;
    }

    public void setCouponFindCouponCountResponseVO(CouponFindCouponCountResponseVO couponFindCouponCountResponseVO) {
        this.couponFindCouponCountResponseVO = couponFindCouponCountResponseVO;
    }

    public String getUseCouponRate() {
        return useCouponRate;
    }

    public void setUseCouponRate(String useCouponRate) {
        this.useCouponRate = useCouponRate;
    }

    public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }


    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public Boolean getStoreLimit() {
        return storeLimit;
    }

    public void setStoreLimit(Boolean storeLimit) {
        this.storeLimit = storeLimit;
    }

    public Integer getWordCount() {
        return wordCount;
    }

    public void setWordCount(Integer wordCount) {
        this.wordCount = wordCount;
    }

    public Boolean getCouponIsOrNo() {
        return couponIsOrNo;
    }

    public void setCouponIsOrNo(Boolean couponIsOrNo) {
        this.couponIsOrNo = couponIsOrNo;
    }

    public Long getMktCouponId() {
        return mktCouponId;
    }

    public void setMktCouponId(Long mktCouponId) {
        this.mktCouponId = mktCouponId;
    }

    public String getPayName() {
        return payName;
    }

    public void setPayName(String payName) {
        this.payName = payName;
    }

    public Integer getPayMoney() {
        return payMoney;
    }

    public void setPayMoney(Integer payMoney) {
        this.payMoney = payMoney;
    }

    public Integer getPayReduced() {
        return payReduced;
    }

    public void setPayReduced(Integer payReduced) {
        this.payReduced = payReduced;
    }

    public Integer getPayId() {
        return payId;
    }

    public void setPayId(Integer payId) {
        this.payId = payId;
    }

    public Integer getActivityInfoType() {
        return activityInfoType;
    }

    public void setActivityInfoType(Integer activityInfoType) {
        this.activityInfoType = activityInfoType;
    }

    public com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO getCouponDetailResponseBO() {
        return CouponDetailResponseBO;
    }

    public void setCouponDetailResponseBO(com.bizvane.mktcenterservice.models.bo.CouponDetailResponseBO couponDetailResponseBO) {
        CouponDetailResponseBO = couponDetailResponseBO;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Boolean getTotalNumType() {
        return totalNumType;
    }

    public void setTotalNumType(Boolean totalNumType) {
        this.totalNumType = totalNumType;
    }

    public BigDecimal getOrderAmount() {
        return orderAmount;
    }

    public void setOrderAmount(BigDecimal orderAmount) {
        this.orderAmount = orderAmount;
    }

    @Override
    public Integer getMbrConditionType() {
        return mbrConditionType;
    }

    @Override
    public void setMbrConditionType(Integer mbrConditionType) {
        this.mbrConditionType = mbrConditionType;
    }

    public String getMbrCondition() {
        return mbrCondition;
    }

    public void setMbrCondition(String mbrCondition) {
        this.mbrCondition = mbrCondition;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public String getSourceWay() {
        return sourceWay;
    }

    public void setSourceWay(String sourceWay) {
        this.sourceWay = sourceWay;
    }

    public Integer getCanCheck() {
        return canCheck;
    }

    public void setCanCheck(Integer canCheck) {
        this.canCheck = canCheck;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public Integer getDayOrMonth() {
        return dayOrMonth;
    }

    public void setDayOrMonth(Integer dayOrMonth) {
        this.dayOrMonth = dayOrMonth;
    }

    public String getPerMensem() {
        return perMensem;
    }

    public void setPerMensem(String perMensem) {
        this.perMensem = perMensem;
    }

    public String getOrderMaxPrice() {
        return orderMaxPrice;
    }

    public void setOrderMaxPrice(String orderMaxPrice) {
        this.orderMaxPrice = orderMaxPrice;
    }

    public String getCanSaveType() {
        return canSaveType;
    }

    public void setCanSaveType(String canSaveType) {
        this.canSaveType = canSaveType;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }
}
